${ _("Open Date:") } | ${ report.order.get_open_date_as_string() } | ${ _("Status:") } | ${ report.order.status_str }
${ _("Supplier:") } | ${ report.order.supplier_name } | ${ _("Branch:") } | ${ report.order.branch_name }
${ _("Transporter:") } | ${ report.order.transporter_name or _("Not Specified") } | ${ _("Agreed Freight:") } | ${ report.get_agreed_freight() }
${ _("Expectd Receival Date:") } % if report.order.expected_receival_date: | ${ report.order.expected_receival_date.strftime('%x') } % else: | ${ _("Not Specified") } % endif % if report.receiving_orders: | ${ _("Received Freight:") } | ${ report.get_received_freight() } % else: |  | % endif